pub struct DistributionScanResults {
most_malicious_file: Option<FileScanResult>,
matched_rules: HashSet<RuleScore>,
inspector_url: Url,
}Expand description
Struct representing the results of a scanned distribution
Fields
most_malicious_file: Option<FileScanResult>The highest-scoring file in this distribution.
matched_rules: HashSet<RuleScore>The unique rules matched across the distribution.
inspector_url: UrlThe inspector URL pointing to this distribution’s base
Implementations
Sourceimpl DistributionScanResults
impl DistributionScanResults
fn empty(inspector_url: Url) -> Self
fn record(&mut self, file_scan_result: FileScanResult)
Sourcepub fn get_most_malicious_file(&self) -> Option<&FileScanResult>
pub fn get_most_malicious_file(&self) -> Option<&FileScanResult>
Get the “most malicious file” in the distribution.
This file with the greatest score is considered the most malicious. If multiple files have the same score, an arbitrary file is picked.
Sourcepub fn get_total_score(&self) -> i64
pub fn get_total_score(&self) -> i64
Calculate the distribution score, counting each matched rule once.
Sourcepub fn inspector_url(&self) -> Option<String>
pub fn inspector_url(&self) -> Option<String>
Return the inspector URL of the most malicious file, or None if there is no most malicious
file